;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "acp" "0.14.3"
  "An ACP (Agent Client Protocol) implementation."
  '((emacs "28.1"))
  :url "https://github.com/xenodium/acp.el"
  :commit "42f5c268537220b94cb1f17e29d3f1f89e6ff0a0"
  :revdesc "42f5c2685372")
